Demos
=====

This section contains a series of demos that highlight ``LEGWORK``'s capabilities
with some example use cases. We'll continue to update this page with new demos
and if you've got an idea for a great use case for ``LEGWORK`` please `open a
pull request <https://www.github.com/TeamLEGWORK/LEGWORK/pulls>`_ and show off your new demo!

.. raw:: html

    <div class="toms-nav-container" style="margin-bottom:40px;">
        <div class="box" data-href="demos/BasicSNRCalculation.html">Calculate SNR of sources</div>
        <div class="box" data-href="demos/TheRoleofEccentricity.html">The Role of Eccentricity</div>
        <div class="box" data-href="demos/CompareSensitivityCurves.html">Compare Sensitivity Curves</div>
        <div class="box" data-href="demos/HorizonDistance.html">Horizon Distance</div>
    </div>

    <div class="toms-nav-container" style="margin-bottom:-50px;">
        <div class="box" data-href="demos/SNROverTime.html">Investigate SNR of source over time</div>
        <div class="box" data-href="demos/VerificationBinaries.html">LISA Verification Binaries</div>
    </div>

.. toctree::
    :titlesonly:
    :maxdepth: 1
    :hidden:

    Calculate SNR of sources <demos/BasicSNRCalculation.ipynb>
    The Role of Eccentricity <demos/TheRoleofEccentricity.ipynb>
    Compare Sensitivity Curves <demos/CompareSensitivityCurves.ipynb>
    Horizon Distance <demos/HorizonDistance.ipynb>
    Investigate SNR of source over time <demos/SNROverTime.ipynb>
    LISA Verification Binaries <demos/VerificationBinaries.ipynb>
